-- Copyright (c) 2010 Ant Kutschera, maxant
-- 
-- This file is part of Ant Kutschera's blog.
-- 
-- This is free software: you can redistribute it and/or modify
-- it under the terms of the Lesser GNU General Public License as published by
-- the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
-- 
-- This software is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- Lesser GNU General Public License for more details.
-- You should have received a copy of the Lesser GNU General Public License
-- along with this software.  If not, see <http://www.gnu.org/licenses/>.

use test;
begin;

-- drop tables, in reverse order not to break fk constraints

drop table if exists comms_log;
drop table if exists purchase;
drop table if exists role;
drop table if exists party;

-- ------------------------------------------------------------
-- the table of people who can log into the site
create table party (
	uid integer not null auto_increment,
	login varchar(255) unique not null, -- the email (username) entered into the site
	password varchar(255) not null, -- the password
    primary key (uid),
    index (login)
) type = innodb;

-- ------------------------------------------------------------
-- create a table for holding the roles of users/customers/staff. 
create table role (
	uid integer not null auto_increment,
	login varchar(50) not null,
	role varchar(50) not null,
	primary key (uid),
    foreign key (login) references party(login),
    index (login)
) type = innodb;

-- ------------------------------------------------------------
-- create a table for holding the messages which this system manages 
create table purchase (
	uid integer not null auto_increment,
	customer varchar(50) not null,
	when_bought datetime not null,
	purchase_uuid varchar(50) not null,
	primary key (uid),
    foreign key (customer) references party(login)
) type = innodb;

-- ------------------------------------------------------------
-- create a table for holding the communications with the partner systems 
create table comms_log (
	uid integer not null auto_increment,
	sender varchar(50) not null,
	purchase_uuid varchar(50) not null,
	offer_id varchar(50) not null,
	product_id varchar(50) not null,
	price double(5,2) not null,
	status varchar(10) not null, -- our status: OFFERED, BOUGHT, CANCELLED. 
	when_sent datetime not null,
	time_taken integer not null,
	primary key (uid),
    foreign key (sender) references party(login)
) type = innodb;

commit;
