/*
 * Copyright (c) 2010 Ant Kutschera, maxant
 * 
 * This file is part of Ant Kutschera's blog.
 * 
 * This is free software: you can redistribute it and/or modify
 * it under the terms of the Lesser GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Lesser GNU General Public License for more details.
 * You should have received a copy of the Lesser GNU General Public License
 * along with this software.  If not, see <http://www.gnu.org/licenses/>.
 */
package uk.co.maxant.test.services;

import java.util.List;
import java.util.concurrent.Future;

/**
 * assists with calls to asynchronous EJB methods.
 * 
 * typically you make all the calls to the async bean and gather the 
 * {@link Future}s together in a list. this class then assists in waiting
 * for the pending results.
 *
 * @param <T> the type of {@link Future} which the bean returns.
 */
public class AsyncTracker <T> {

	/**
	 * @param results the results to wait for. blocks until they are cancelled or done.
	 */
	public void waitForCompletion(List<Future<T>> results){
		boolean allFinished = false;
		while(!allFinished){
			allFinished = true;
			for(Future<T> result : results){
				if(!result.isDone() && !result.isCancelled()){
					allFinished = false;
					break;
				}
			}
			try {
				//let other threads have a chance!
				Thread.sleep(50);
			} catch (InterruptedException e) {
				//oh well, guess we wont be polite and wait
			}
		}
	}
}
