/*
 * Copyright (c) 2010 Ant Kutschera, maxant
 * 
 * This file is part of Ant Kutschera's blog.
 * 
 * This is free software: you can redistribute it and/or modify
 * it under the terms of the Lesser GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Lesser GNU General Public License for more details.
 * You should have received a copy of the Lesser GNU General Public License
 * along with this software.  If not, see <http://www.gnu.org/licenses/>.
 */
package uk.co.maxant.test.services;

import javax.annotation.Resource;
import javax.ejb.ActivationConfigProperty;
import javax.ejb.MessageDriven;
import javax.jms.JMSException;
import javax.jms.Message;
import javax.jms.MessageListener;
import javax.jms.TextMessage;
import javax.mail.Address;
import javax.mail.MessagingException;
import javax.mail.Session;
import javax.mail.Transport;
import javax.mail.internet.InternetAddress;
import javax.mail.internet.MimeMessage;

/**
 * Message-Driven Bean which sends emails.
 * 
 */
@MessageDriven(activationConfig = { @ActivationConfigProperty(propertyName = "destinationType", propertyValue = "javax.jms.Queue") }, mappedName = "jms/destinationResource")
public class MailSenderBean implements MessageListener {

	public static final String TO = "_to";

	@Resource(name = "mail/Session")
	private Session mailSession;

	public MailSenderBean() {
	}

	/**
	 * @see MessageListener#onMessage(Message)
	 */
	public void onMessage(Message msg) {
		TextMessage tm = (TextMessage) msg;
		try {
			String text = tm.getText();
			System.out.println("i got a message: " + text);

			Address[] adds = new InternetAddress[1];
			adds[0] = new InternetAddress(tm.getStringProperty(TO));
			javax.mail.Message mmsg = new MimeMessage(mailSession);
			mmsg.setText(text);
			Transport.send(mmsg, adds);

		} catch (JMSException e) {
			// ideally handle with some kind of error handler which notifies
			// someone
			// or puts this in a DLQ so it can be processed at another time.
			e.printStackTrace();
		} catch (MessagingException e) {
			// ideally handle with some kind of error handler which notifies
			// someone
			// or puts this in a DLQ so it can be processed at another time.
			e.printStackTrace();
		}
	}

}
