/*
 * Copyright (c) 2010 Ant Kutschera, maxant
 * 
 * This file is part of Ant Kutschera's blog.
 * 
 * This is free software: you can redistribute it and/or modify
 * it under the terms of the Lesser GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Lesser GNU General Public License for more details.
 * You should have received a copy of the Lesser GNU General Public License
 * along with this software.  If not, see <http://www.gnu.org/licenses/>.
 */
package uk.co.maxant.test.services;

import java.util.UUID;
import java.util.concurrent.Future;

import javax.ejb.Local;

import uk.co.maxant.test.data.Product;
import uk.co.maxant.test.ws.Offer;
import uk.co.maxant.test.ws.PricingSystem;
import uk.co.maxant.test.ws.PricingSystemException_Exception;

/**
 * calls a partner system.
 */
@Local
public interface PartnerBeanLocal {

	/**
	 * @see PricingSystem#getPrice(String)
	 * 
	 * call this asynchronously, because it takes a while to return. good opportunity to parallelise
	 * in the case where you would call this method multiple times within a call from the client.
	 */
	Future<Offer> getOffer(Product p, UUID u);

	/**
	 * @throws PricingSystemException_Exception 
	 * @see PricingSystem#purchaseOffer(String)
	 */
	void purchase(String offerId) throws PricingSystemException_Exception;
	
	/**
	 * @throws PricingSystemException_Exception 
	 * @see PricingSystem#cancel(String)
	 */
	void cancel(String offerId) throws PricingSystemException_Exception;
}
