/*
 * Copyright (c) 2010 Ant Kutschera, maxant
 * 
 * This file is part of Ant Kutschera's blog.
 * 
 * This is free software: you can redistribute it and/or modify
 * it under the terms of the Lesser GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Lesser GNU General Public License for more details.
 * You should have received a copy of the Lesser GNU General Public License
 * along with this software.  If not, see <http://www.gnu.org/licenses/>.
 */
package uk.co.maxant.test.services;

import java.util.Set;

import javax.interceptor.AroundInvoke;
import javax.interceptor.InvocationContext;
import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;

import uk.co.maxant.test.BusinessException;

/**
 * an aspect (AOP) for validating method inputs.
 */
public class ValidationInterceptor {

    private Validator validator;

	//needs this, otherwise wont run at runtime!
	public ValidationInterceptor() {
    	ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
    	//cache the factory somewhere
    	validator = factory.getValidator();
	}

	/**
	 * this method is an aspect which has been configured to be called around the execute method,
	 * using the annotation @Inteceptors.
	 */
	@AroundInvoke
	public Object intercept(InvocationContext ctx) throws Exception {
		long start = System.nanoTime();

		String result = "";
		boolean hasValidationErrors = false;
		for(Object o : ctx.getParameters()){
			Set<ConstraintViolation<Object>> vs = validator.validate(o);
			if(!vs.isEmpty()){
				//invalid!
				hasValidationErrors = true;
				result += "ValidationError: " + o + ": " + vs + "\r\n";
			}
		}

		System.out.println("validation completed on " + ctx.getMethod().getName() + " in " + ((System.nanoTime()-start)/1000000.0) + "ms. valid=" + !hasValidationErrors);
		if(!hasValidationErrors){
			Object o = ctx.proceed();
			return o;
		}else{
			throw new BusinessException(result);
		}

	}

}
