/*
 * Copyright (c) 2010 Ant Kutschera, maxant
 * 
 * This file is part of Ant Kutschera's blog.
 * 
 * This is free software: you can redistribute it and/or modify
 * it under the terms of the Lesser GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Lesser GNU General Public License for more details.
 * You should have received a copy of the Lesser GNU General Public License
 * along with this software.  If not, see <http://www.gnu.org/licenses/>.
 */
package uk.co.maxant.test.ws;

import java.util.Date;
import java.util.UUID;

import javax.xml.bind.annotation.XmlElement;

import uk.co.maxant.test.ws.PricingSystem.Status;

/**
 * an offer for the product. such offers may be subsequently bought.
 * 
 * note how the @XmlElement annotation is only required on those fields which are 
 * not automatically added to the XSD. indeed if we annotate all fields, the WSDL 
 * gives off server 500 errors! load a shite.
 */
public class Offer {

	private static final long VALID_DURATION = 30*1000L;

	private String productId;
	
	@XmlElement
	private String offerId = UUID.randomUUID().toString();
	
	private Double price;

	@XmlElement
	private Date validUntil = new Date(System.currentTimeMillis() + VALID_DURATION);
	
	protected PricingSystem.Status status = Status.OFFERED;

	public String getOfferId() {
		return offerId;
	}

	public Double getPrice() {
		return price;
	}

	public void setPrice(Double price) {
		this.price = price;
	}

	public String getProductId() {
		return productId;
	}

	public void setProductId(String productId) {
		this.productId = productId;
	}

	public Date getValidUntil() {
		return validUntil;
	}
	
	public boolean hasExpired(){
		return System.currentTimeMillis() > validUntil.getTime();
	}

	public PricingSystem.Status getStatus() {
		return status;
	}
	
	public Date getCreated(){
		return new Date(validUntil.getTime() - VALID_DURATION);
	}

	@Override
	public int hashCode() {
		return offerId.hashCode();
	}

	@Override
	public String toString() {
		return "Offer [offerId=" + offerId + ", price=" + price
				+ ", productId=" + productId + ", status=" + status
				+ ", validUntil=" + validUntil + "]";
	}

}
