/*
 * Copyright (c) 2010 Ant Kutschera, maxant
 * 
 * This file is part of Ant Kutschera's blog.
 * 
 * This is free software: you can redistribute it and/or modify
 * it under the terms of the Lesser GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Lesser GNU General Public License for more details.
 * You should have received a copy of the Lesser GNU General Public License
 * along with this software.  If not, see <http://www.gnu.org/licenses/>.
 */
package uk.co.maxant.test.ui;

import java.io.IOException;

import javax.annotation.security.RolesAllowed;
import javax.ejb.EJB;
import javax.ejb.EJBException;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.annotation.WebServlet;

import uk.co.maxant.test.Roles;
import uk.co.maxant.test.services.OrchestrationBeanLocal;

/**
 * Servlet implementation class SevenServlet
 */
@WebServlet(name = "SevenServlet", urlPatterns = { "/SevenServlet" })
@RolesAllowed(Roles.REGISTERED)
public class SevenServlet extends HttpServlet {

	private static final long serialVersionUID = 1L;

	public static final String RESULT = "_result";

	/**
	 * the following is a local bean and can be accessed either using the @EJB
	 * annotation, or using the @Resource annotation, as shown below.
	 * the "java:app" part means its deployed as part of this app, in the 
	 * SevenEJB module and has the name SevenBean.
	 * notice how we have a reference to the beans interface and not the impl.
	 */
	@EJB
//	@Resource(name="java:app/SevenEJB/SevenBean")
	private OrchestrationBeanLocal ejb;

	/**
	 * to access a remote bean we just use the @EJB annotation.
	 * theoretically this should also work:
	 * 
	 *   @Resource(name="java:global/Seven/SevenEJB/SevenBean")
	 *   
	 * but for some reason it doesnt!
	 * notice how we have a reference to the beans interface and not impl.
	 */
	//@EJB
	//private EJBSevenRemote ejbRemote;
	
    public SevenServlet() {
    }

	/**
	 * @see HttpServlet#doGet(HttpServletRequest request, HttpServletResponse response)
	 */
	protected void doGet(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
		processRequest(request, response);
	}

	/**
	 * @see HttpServlet#doPost(HttpServletRequest request, HttpServletResponse response)
	 */
	protected void doPost(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
		processRequest(request, response);
	}

	/**
	 * Processes requests for both HTTP <code>GET</code> and <code>POST</code> methods.
	 * @param request servlet request
	 * @param response servlet response
	 * @throws ServletException if a servlet-specific error occurs
	 * @throws IOException if an I/O error occurs
	 */
	protected void processRequest(HttpServletRequest request,
			HttpServletResponse response) throws ServletException, IOException {

		response.setContentType("text/html;charset=UTF-8");
		
		//set the command
		String command = request.getParameter("error");
		if(command == null){
			command = "none";
		}

		//call the orchestration service to carry out transacted business logic
		String result = null;
		try{
			result = ejb.execute(command);
		}catch(Exception e){
			if(e instanceof EJBException){
				result = ((EJBException)e).getCause().getMessage();
			}else{
				e.printStackTrace();
				result = e.getMessage();
			}
		}
		
		//finished the logic (controller), now for the presentation - let a JSP do it
		request.setAttribute(RESULT, result);
		request.getRequestDispatcher("/servletResult.jsp").forward(request, response);
	}

}
